@@ -28,7 +28,6 @@ THE SOFTWARE
 
 // Platform-specific stuff
 #include "OgrePlatform.h"
-#include "OgreWorkarounds.h"
 
 #include <string>
 
@@ -65,10 +64,10 @@ THE SOFTWARE
 namespace Ogre {
     // Define ogre version
     #define OGRE_VERSION_MAJOR 2
-    #define OGRE_VERSION_MINOR 2
-    #define OGRE_VERSION_PATCH 4
+    #define OGRE_VERSION_MINOR 3
+    #define OGRE_VERSION_PATCH 0
     #define OGRE_VERSION_SUFFIX ""
-    #define OGRE_VERSION_NAME "Cerberus"
+    #define OGRE_VERSION_NAME "Daedalus"
 
     #define OGRE_VERSION    ((OGRE_VERSION_MAJOR << 16) | (OGRE_VERSION_MINOR << 8) | OGRE_VERSION_PATCH)
 
@@ -145,7 +144,7 @@ namespace Ogre {
     typedef unsigned int uint;
     typedef unsigned long ulong;
 
-    #if __cplusplus >= 201103L
+    #if __cplusplus >= 201103L || ( defined(_MSC_VER) && _MSC_VER >= 1800 )
     #define register
     #endif
 // Pre-declare classes
@@ -266,8 +265,10 @@ namespace Ogre {
     class ManualObject;
     class MovableObject;
     class MovablePlane;
+#ifdef _OGRE_MULTISOURCE_VBO
     class MultiSourceVertexBufferPool;
-	class Node;
+#endif
+    class Node;
     class NodeMemoryManager;
     struct ObjectData;
     class ObjectMemoryManager;
@@ -292,6 +293,7 @@ namespace Ogre {
     class Ray;
     class RaySceneQuery;
     class RaySceneQueryListener;
+    class ReadOnlyBufferPacked;
     class Rectangle2D;
     class Renderable;
     class RenderPriorityGroup;
@@ -308,6 +310,7 @@ namespace Ogre {
     class ResourceGroupManager;
     class ResourceManager;
     class Root;
+    class RootLayout;
     class SceneManager;
     class SceneManagerEnumerator;
     class SceneNode;
@@ -625,6 +628,8 @@ namespace std
 // are passed by reference & need to be everywhere in headers (thus affecting compilation times)
 namespace Ogre
 {
+    template <typename, typename> class STLAllocator;
+
     template <typename T, typename A = STLAllocator<T, GeneralAllocPolicy> >
     class StdVector;
 
@@ -645,6 +650,7 @@ namespace Ogre
 }
 
 #include "OgreAssert.h"
+#include "OgreWorkarounds.h"
 
 #endif // __OgrePrerequisites_H__
 
