@@ -10,7 +10,8 @@ var class_ogre_1_1_d3_d11_h_l_s_l_program =
       [ "LF_INCLUDE_NON_RELOADABLE", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a1aa750a4b994f2b1066220936cdfdb94a6ee542226e1cf18df28ab88426be6809", null ],
       [ "LF_ONLY_UNREFERENCED", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a1aa750a4b994f2b1066220936cdfdb94a70589e0b87b09b0a4fd98ce490dc9782", null ],
       [ "LF_ONLY_UNREFERENCED_INCLUDE_NON_RELOADABLE", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a1aa750a4b994f2b1066220936cdfdb94ae5f2eca654bd810da4c774570a5b4b77", null ],
-      [ "LF_PRESERVE_STATE", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a1aa750a4b994f2b1066220936cdfdb94ad83abf165de5cfa1a4c8e0cd5471ad2c", null ]
+      [ "LF_PRESERVE_STATE", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a1aa750a4b994f2b1066220936cdfdb94ad83abf165de5cfa1a4c8e0cd5471ad2c", null ],
+      [ "LF_MARKED_FOR_RELOAD", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a1aa750a4b994f2b1066220936cdfdb94a146041ec2a8b5178e5ad541d129c22eb", null ]
     ] ],
     [ "LoadingState", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a07e619aa09d3bc6789a6667cb4fc572c", [
       [ "LOADSTATE_UNLOADED", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a07e619aa09d3bc6789a6667cb4fc572ca28d463296cacdfc115dbc3fb02d00e94", null ],
@@ -18,7 +19,8 @@ var class_ogre_1_1_d3_d11_h_l_s_l_program =
       [ "LOADSTATE_LOADED", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a07e619aa09d3bc6789a6667cb4fc572caa38cbef7605fc4bff6da2f34599ace8f", null ],
       [ "LOADSTATE_UNLOADING", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a07e619aa09d3bc6789a6667cb4fc572ca4228d390b3a9ed614001db177d1f441e", null ],
       [ "LOADSTATE_PREPARED", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a07e619aa09d3bc6789a6667cb4fc572ca133a073b86c346096237063f99870fc1", null ],
-      [ "LOADSTATE_PREPARING", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a07e619aa09d3bc6789a6667cb4fc572cab43c913411f4a96722902f17b88f10fb", null ]
+      [ "LOADSTATE_PREPARING", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a07e619aa09d3bc6789a6667cb4fc572cab43c913411f4a96722902f17b88f10fb", null ],
+      [ "LOADSTATE_UNLOADED_MARKED_FOR_RELOAD", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a07e619aa09d3bc6789a6667cb4fc572ca0c7b0873cacd42dec59d948b9bd28062", null ]
     ] ],
     [ "D3D11HLSLProgram", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a85d86c3f9168e361c57a53305c985683", null ],
     [ "~D3D11HLSLProgram", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#aabc74a1b85c3201520034773e438dce4", null ],
@@ -26,7 +28,7 @@ var class_ogre_1_1_d3_d11_h_l_s_l_program =
     [ "_fireLoadingComplete", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a893c7a150edb48a25e5df700cfc194eb", null ],
     [ "_firePreparingComplete", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a77d5f72e02500f6db6f460bb48eac721", null ],
     [ "_fireUnloadingComplete", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a4b5d014a4d078b7893cce480b264c493", null ],
-    [ "_getBindingDelegate", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a3738e5bfb9a287279bbbbfa0271bc05c", null ],
+    [ "_getBindingDelegate", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#abd1101f548470b82fc6b130a3241aab7", null ],
     [ "_notifyOrigin", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a3d111616339484f39c9456eeec6fd843", null ],
     [ "addListener", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a5513ffce404b14cff72846318b018d32", null ],
     [ "buildConstantDefinitions", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a8135328bbdf38f8e44c959757ea18183", null ],
@@ -44,52 +46,53 @@ var class_ogre_1_1_d3_d11_h_l_s_l_program =
     [ "escalateLoading", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a367f6fe60bb211cb4c32e3825ca67e4c", null ],
     [ "getBuildParametersFromReflection", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a1645577e44bbb3d3877c9e57af947f12", null ],
     [ "getColumnMajorMatrices", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a7821845efe3a09f5823007849ec7ce75", null ],
-    [ "getCompatibleTarget", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a0648a6831b24c82b3bb6873a5b593f54", null ],
+    [ "getCompatibleTarget", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a98f3767e8f6ab3d880c3132c38e4287e", null ],
     [ "getComputeGroupDimensions", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a39e694fafadbf623d7e865bc30b3362b", null ],
-    [ "getComputeShader", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ada27c7bcddb30e3a42a42521d11d42ed", null ],
+    [ "getComputeShader", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a66962698af5439e32e44afd60eb9287c", null ],
     [ "getConstantBuffers", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ac6be99b424445fa7baa464b3063b6bab", null ],
-    [ "getConstantDefinitions", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ac281d547b47b872fe35e1e60fe07612a", null ],
-    [ "getCreator", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a741224f735dfd9ce324a4e8e621d868c", null ],
+    [ "getConstantDefinitions", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ac474e5bfa6c4bfc8d3b80c8c855f5e1a", null ],
+    [ "getCreator", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a1686b8aef3b2c8d3892ae453086073c4", null ],
     [ "getDefaultParameters", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a04675a861df66c30e431f95aa84320f5", null ],
-    [ "getDomainShader", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#af845b7c0a0d63d1fb568c1645fdd2e48", null ],
+    [ "getDomainShader", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a4976123aaaa8df43f5914e005737b079", null ],
     [ "getEnableBackwardsCompatibility", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a22e41e91fec8b452c268bf605a115f88", null ],
     [ "getEnableIncludeHeader", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#af12e7c538f0d185ad3d2353ac1c96664", null ],
-    [ "getEntryPoint", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a24a5da0e59effe68e0aaeb04ce51a058", null ],
-    [ "getGeometryShader", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a183faffc570d24e527ee7aef5f5c90cd", null ],
-    [ "getGroup", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a382919945c07a6a13136889ad3fbf578", null ],
+    [ "getEntryPoint", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a71656bdb54170a7f656f28b01d44f406", null ],
+    [ "getGeometryShader", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a04f916a89bdc4b4189067a7eeab3019a", null ],
+    [ "getGroup", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a6cfc6014da843369b2619d1d7d807569", null ],
     [ "getHandle", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a2298551707debaf774d577e643ee856a", null ],
-    [ "getHullShader", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a2c7a7854590bb7664adeec70bf5944c2", null ],
-    [ "getInputParamDesc", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a4e3b395719588541e089d4af3206898a", null ],
-    [ "getLanguage", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#aa207714ae38ecb62bf8899a884e11c37", null ],
-    [ "getLayoutForPso", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a33252ef9ca6ebcb449fecb5560f8a3e1", null ],
+    [ "getHullShader", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#aa5309bf84c4a3dc947b8dbe97564ab4a", null ],
+    [ "getInputParamDesc", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a1688b2d4d1e251a7b70858599555fb33", null ],
+    [ "getLanguage", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ada386ef97a3a5408b4445b74f71b072f", null ],
+    [ "getLayoutForPso", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#af3fa88ed07d58eca1fbd8a0c4566f9c5", null ],
     [ "getLoadingState", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a1e90ade99935ef70ec5b199243bf995b", null ],
-    [ "getManualNamedConstantsFile", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a88eea9caf28dc6c73d8594b75b4adc45", null ],
-    [ "getMicroCode", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a542e9f384a5b365838fc2bdd1f653c46", null ],
-    [ "getName", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a0646fba8aa0242c6b389d73f47ebe41b", null ],
+    [ "getManualNamedConstantsFile", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#aca23cde99e1b29b997bf053742006dc6", null ],
+    [ "getMicroCode", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#af51c04093bee190e3465654c937b4265", null ],
+    [ "getName", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a5d3962a2bef3bd77de412c8207975caf", null ],
     [ "getNameForMicrocodeCache", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a87bc3192e9b705da1ae6841ef1db6294", null ],
     [ "getNumberOfPosesIncluded", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#af0be69f3df55f71c0bded2e36c89dfa6", null ],
+    [ "getNumClipDistances", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a7ffe6edc1d1ccb636a75cb185959bf0c", null ],
     [ "getNumInputs", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#aff258b3dc81de0a376a8beaad3822af6", null ],
     [ "getNumOutputs", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a7e03b89621f39735d819ae2371db5e23", null ],
-    [ "getOrigin", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ab298af22eef082938fac77ee9ae7c694", null ],
-    [ "getOutputParamDesc", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a1dff1b1e09f76142e30660fa94a67e49", null ],
-    [ "getParamDictionary", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ae3e13925bde11db245f6c9bbf5031a93", null ],
-    [ "getParamDictionary", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a0f55da0550a7e1ab70a1c8bf598a3e20", null ],
+    [ "getOrigin", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a8ab9418311a7b4a116139a7871e57a4b", null ],
+    [ "getOutputParamDesc", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a2c583a65b857449a701b364a5aae4cac", null ],
+    [ "getParamDictionary", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a9dffcf1a2d754e63e98770e5cf2cd9ee", null ],
+    [ "getParamDictionary", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a3e314036bfd3198e89bd1d250f5eb6a1", null ],
     [ "getParameter", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a01a6e571941916969316ab23c5ee4739", null ],
-    [ "getParameters", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ad4b984bfbf148ddb3310b3d0ba8a9d5d", null ],
+    [ "getParameters", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#acce55ed43f888d8c4c5ed5c5aaf9d1db", null ],
     [ "getPassFogStates", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a0f581ec108f9fe82dd89539a0aba4336", null ],
     [ "getPassSurfaceAndLightStates", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#af843c9fdc4918e9201e8381ed2a1617e", null ],
     [ "getPassTransformStates", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a64cdfefb7694f74a93c299454d40692d", null ],
-    [ "getPixelShader", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a09752e9b5da3a67683754afafce58265", null ],
-    [ "getPreprocessorDefines", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a7a3e9f1f9288714b5567d62ca03a0ea9", null ],
+    [ "getPixelShader", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a3efe8b1cb897c3214a7b29ecfc3ba851", null ],
+    [ "getPreprocessorDefines", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a369f657e0bc6e957388835392ed7bd95", null ],
     [ "getSize", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a0617d9f04ca03bd25f4bde201e6ac13b", null ],
-    [ "getSource", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a27ab608031953550438c054e74b147fc", null ],
-    [ "getSourceFile", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a7e88275173a2737c60d92504eea4c304", null ],
+    [ "getSource", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#aef4abc028e1309b9998666a126019a5e", null ],
+    [ "getSourceFile", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a93d9189744cc0d7188fc9a06eece58eb", null ],
     [ "getStateCount", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ade85e4d5579519e4117a84789c0ae8fd", null ],
     [ "getSubroutineSlot", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a029cdbb396d59cb87790cb7d8d3cba72", null ],
-    [ "getSyntaxCode", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a6b900799ceda4093a0dd81fd8f7d1965", null ],
-    [ "getTarget", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a830c6b4498e5a82ed7537dc72dff7699", null ],
+    [ "getSyntaxCode", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a901cae29fc84030c1040fc72db9d0691", null ],
+    [ "getTarget", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a648b8f0a408b9843bddcbdd7f9739f0c", null ],
     [ "getType", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#aac8cad21ade016a741d6acd3660b0185", null ],
-    [ "getVertexShader", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#aee0cfc26b95835a423c0fb024594b2dd", null ],
+    [ "getVertexShader", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a922a1df84aca64ec2dd9521d1bbbd8ee", null ],
     [ "hasCompileError", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a41ca5ed671aeded51032646285f0a756", null ],
     [ "hasDefaultParameters", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a466348cfefa74a767ed8b813e2caec6f", null ],
     [ "isAdjacencyInfoRequired", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a6e4126e3d4bdc85eb3bfb4530c8e8249", null ],
@@ -107,22 +110,24 @@ var class_ogre_1_1_d3_d11_h_l_s_l_program =
     [ "isVpAndRtArrayIndexFromAnyShaderRequired", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a83ff552868d41fa0daa9180913456c9e", null ],
     [ "load", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a699d1c851f494a8d5d23d23b695ceb47", null ],
     [ "loadFromSource", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a385cc4247bcc3625001cd3062bb9992b", null ],
+    [ "markForReload", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a6bdd32464ce1df547d34a0739e4c3592", null ],
     [ "operator delete", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
     [ "operator delete", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#acb46d4b0a597156d9ba5abc39d127792", null ],
     [ "operator delete", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a1c727e879a260c37b00ce5505fe8e144", null ],
     [ "operator delete[]", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
     [ "operator delete[]", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a595ea4c05da8aa987d3800e65d23355d", null ],
-    [ "operator new", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ac4bdf968b7b9af8a5239a27da73d5711", null ],
-    [ "operator new", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a421b197ca3a38da17e2eb1531a645fa2", null ],
-    [ "operator new", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ab78a921e54419be677839cdf15d1f0b8", null ],
-    [ "operator new[]", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#afa2943846ba6a2b5824a12857139cf5e", null ],
-    [ "operator new[]", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a4be37baef81876985aa1071ad5acc6dd", null ],
+    [ "operator new", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
+    [ "operator new", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ab422c67a2c8844f410fe822a357cba3b", null ],
+    [ "operator new", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
+    [ "operator new[]", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#adce32528577d71b228692df906ecd17c", null ],
+    [ "operator new[]", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
     [ "prepare", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a350b287fa3e83a389221274f68760008", null ],
     [ "reinterpretGSForStreamOut", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a585368f2e75a4e78b36a4048a9300563", null ],
     [ "reload", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a5016aec1762b026997ddd346775879ef", null ],
     [ "removeListener", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a3c49142f739ba8fb56d6e7b3db235fb7", null ],
     [ "resetCompileError", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a2443ed18b880eb939123bb8daf9165c7", null ],
     [ "setAdjacencyInfoRequired", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a39b43157d6b40626101e5de8f9c77bf5", null ],
+    [ "setAutoReflectArrayBindingsInRootLayout", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ae4d9c0afca2284a5e0972bdf8b6ff543", null ],
     [ "setBackgroundLoaded", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ae0a0007de944eb3c2f933a372a752b35", null ],
     [ "setBuildParametersFromReflection", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a91663e447c0a4addd142cc2be5c1800b", null ],
     [ "setColumnMajorMatrices", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ae504a6cf2f2f705a50a9066b5ea819df", null ],
@@ -134,11 +139,14 @@ var class_ogre_1_1_d3_d11_h_l_s_l_program =
     [ "setManualNamedConstants", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ad12bddb95c7311f31f602cb70b8350c5", null ],
     [ "setManualNamedConstantsFile", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#afdadf659ccac4facdc86e55a266eebcf", null ],
     [ "setMorphAnimationIncluded", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a843c706f65d219c1d04b8aeacc4bd3c8", null ],
+    [ "setNumClipDistances", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a33dbdfb93317b9f8192e2272f1679f28", null ],
     [ "setParameter", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ace884b65b722ead9b920b9abf27bf815", null ],
     [ "setParameterList", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ae356913ccefbebc4f0119a0599a406fc", null ],
     [ "setPoseAnimationIncluded", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a848bf4164963cf8c0435c972eb717e0f", null ],
+    [ "setPrefabRootLayout", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a56813acb2feeded63abaff6f9e8eed41", null ],
     [ "setPreprocessorDefines", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a9305d93d797b39e4f69fa55dbaed1e87", null ],
-    [ "setShaderMacros", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ab3e938cd5942848fe158ba8d6dfd6844", null ],
+    [ "setReplaceVersionMacro", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a0723cad43b2bfee112cc73a92c886d0d", null ],
+    [ "setRootLayout", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#adf97e56ab636784432fa469f3539caab", null ],
     [ "setSkeletalAnimationIncluded", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#af337509a5342cb707df4df78337756ae", null ],
     [ "setSource", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a300833abd29aa42acb5e6c48ae7c40ea", null ],
     [ "setSource", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a94c9ce889770e95c0cdc541f8675f06f", null ],
@@ -152,6 +160,7 @@ var class_ogre_1_1_d3_d11_h_l_s_l_program =
     [ "setVpAndRtArrayIndexFromAnyShaderRequired", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a633efc296c4dffefe10f7a1e3da26e2d", null ],
     [ "touch", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ae229b1f58092109adef55bfc6f864d79", null ],
     [ "unload", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#aa31bef1bfaa87731622e56f11b548e27", null ],
+    [ "unsetRootLayout", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#ada4a9ab6c809e2930a74932a51dd5874", null ],
     [ "mReinterpretingGS", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a9174dcd088c729234de410a0d640f090", null ],
     [ "msEnableIncludeHeaderCmd", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#abe36db3d6c7275c9fd7c50a6ffba6cb8", null ],
     [ "OGRE_AUTO_MUTEX", "class_ogre_1_1_d3_d11_h_l_s_l_program.html#a104d9db8bfcff1f37b29157bbe070f7a", null ]
