@@ -7,8 +7,8 @@ var class_ogre_1_1_d3_d9_render_system =
     ] ],
     [ "D3D9RenderSystem", "class_ogre_1_1_d3_d9_render_system.html#a14dbc5ade147a1ff11f7f7e2dff70053", null ],
     [ "~D3D9RenderSystem", "class_ogre_1_1_d3_d9_render_system.html#a5fcc5cf6ff472ea542bb69aeb48b9b01", null ],
-    [ "_addManualDepthBuffer", "class_ogre_1_1_d3_d9_render_system.html#a4bd873491b6eb59dbadce27e1d88e902", null ],
-    [ "_addMetrics", "class_ogre_1_1_d3_d9_render_system.html#ab4c80dcdf2f20df687035fb8c72797ea", null ],
+    [ "_addManualDepthBuffer", "class_ogre_1_1_d3_d9_render_system.html#aa08b2dd098cf209cd3f1102c46cf3c21", null ],
+    [ "_addMetrics", "class_ogre_1_1_d3_d9_render_system.html#a54ebaf329b7173ef06cbfcd0dff64cb5", null ],
     [ "_beginFrame", "class_ogre_1_1_d3_d9_render_system.html#a3b458922197e5a3502b29e9bfe016cdf", null ],
     [ "_beginFrameOnce", "class_ogre_1_1_d3_d9_render_system.html#ada60763d5b8ef9cfba1c77ecfe3e4188", null ],
     [ "_checkTextureFilteringSupported", "class_ogre_1_1_d3_d9_render_system.html#a09b739bb7b2d3c3aff1fecece56e9baa", null ],
@@ -18,8 +18,9 @@ var class_ogre_1_1_d3_d9_render_system =
     [ "_clearStateAndFlushCommandBuffer", "class_ogre_1_1_d3_d9_render_system.html#a2ee7864ccf7579b46082f2b694d6586a", null ],
     [ "_convertOpenVrProjectionMatrix", "class_ogre_1_1_d3_d9_render_system.html#ad05022b35e523cdba22d993a51fc4b78", null ],
     [ "_convertProjectionMatrix", "class_ogre_1_1_d3_d9_render_system.html#a2228dcfce5ec360f8f421f9544872f01", null ],
-    [ "_createDepthBufferFor", "class_ogre_1_1_d3_d9_render_system.html#abd43de1c83a36316e1c62cda7d2ef31f", null ],
-    [ "_createRenderWindow", "class_ogre_1_1_d3_d9_render_system.html#a35c27788a6eedcc44b520fc17077f770", null ],
+    [ "_createDepthBufferFor", "class_ogre_1_1_d3_d9_render_system.html#a949fa1062460e37e5a9ca9815486d56d", null ],
+    [ "_createRenderWindow", "class_ogre_1_1_d3_d9_render_system.html#ab120136ac65bef3def024f27532c03fb", null ],
+    [ "_createRenderWindow", "class_ogre_1_1_d3_d9_render_system.html#ad8469f0aa267bf80682e08cdd0a41aaf", null ],
     [ "_createRenderWindows", "class_ogre_1_1_d3_d9_render_system.html#af2e127de3a611d547520a667fe067f29", null ],
     [ "_createRenderWindows", "class_ogre_1_1_d3_d9_render_system.html#a2d1a6b690161dcd972d7cfc13b59dc10", null ],
     [ "_dereferenceSharedDepthBuffer", "class_ogre_1_1_d3_d9_render_system.html#a24604b2949b6dfe884b7d87b9ebaf0cc", null ],
@@ -35,9 +36,8 @@ var class_ogre_1_1_d3_d9_render_system =
     [ "_dispatch", "class_ogre_1_1_d3_d9_render_system.html#a861e0f346f675c6fa688e522c0754ad8", null ],
     [ "_endFrame", "class_ogre_1_1_d3_d9_render_system.html#aff3564dce1811300a2d4e7a65e4e9c66", null ],
     [ "_endFrameOnce", "class_ogre_1_1_d3_d9_render_system.html#a7918658f5c363617c53f6179d23e63fc", null ],
-    [ "_executeResourceTransition", "class_ogre_1_1_d3_d9_render_system.html#a0c157a039184ac45bf575fb0d00601de", null ],
-    [ "_getCurrentRenderViewport", "class_ogre_1_1_d3_d9_render_system.html#a8bd773d225cea6b0aee804c3c5b2a945", null ],
-    [ "_getDefaultViewportMaterialScheme", "class_ogre_1_1_d3_d9_render_system.html#a3c2256419916cbf7777c9bf8b1f3d716", null ],
+    [ "_getCurrentRenderViewport", "class_ogre_1_1_d3_d9_render_system.html#a51cbd7a790f8bad97ac8983e00fcbfb2", null ],
+    [ "_getDefaultViewportMaterialScheme", "class_ogre_1_1_d3_d9_render_system.html#a6a719f86bcb5458d55bd0cd887f3ed3e", null ],
     [ "_getDepthStencilFormatFor", "class_ogre_1_1_d3_d9_render_system.html#a756e9227a2d0147e31100ce041d4f9cb", null ],
     [ "_hlmsBlendblockCreated", "class_ogre_1_1_d3_d9_render_system.html#ac33cff318b8ae9c4f1b9a35b97250322", null ],
     [ "_hlmsBlendblockDestroyed", "class_ogre_1_1_d3_d9_render_system.html#a494fc2da2cb98d016803868180cdcbb9", null ],
@@ -49,9 +49,9 @@ var class_ogre_1_1_d3_d9_render_system =
     [ "_hlmsPipelineStateObjectDestroyed", "class_ogre_1_1_d3_d9_render_system.html#a9120e92d45da9294119cc88f3ad8bd19", null ],
     [ "_hlmsSamplerblockCreated", "class_ogre_1_1_d3_d9_render_system.html#a5df47d554298bec7130841b77b301034", null ],
     [ "_hlmsSamplerblockDestroyed", "class_ogre_1_1_d3_d9_render_system.html#ab4c5501448cb75312320baac3fb05d1d", null ],
-    [ "_initialise", "class_ogre_1_1_d3_d9_render_system.html#adbab61a827e8d9fd7c669ae7824d1b4f", null ],
+    [ "_initialise", "class_ogre_1_1_d3_d9_render_system.html#acb3570aea045a845b12171db4458b21c", null ],
     [ "_makeRsProjectionMatrix", "class_ogre_1_1_d3_d9_render_system.html#a37208fe7f2e29b71a2972defdf9d04b2", null ],
-    [ "_pauseFrame", "class_ogre_1_1_d3_d9_render_system.html#a65482df447bced296f056b0962ceabbe", null ],
+    [ "_pauseFrame", "class_ogre_1_1_d3_d9_render_system.html#a6eba351f3da4503d5c3b1d67789f2754", null ],
     [ "_render", "class_ogre_1_1_d3_d9_render_system.html#a05164d117632c60852cbcc6c21fd957b", null ],
     [ "_render", "class_ogre_1_1_d3_d9_render_system.html#a1224b23cee7a4967f75cb947ba185b99", null ],
     [ "_render", "class_ogre_1_1_d3_d9_render_system.html#ac95209c361f6d09fb6e0af0f6d4b4107", null ],
@@ -65,8 +65,6 @@ var class_ogre_1_1_d3_d9_render_system =
     [ "_renderNoBaseInstance", "class_ogre_1_1_d3_d9_render_system.html#adf4faec7fb049bc5092605c526cf1d72", null ],
     [ "_renderNoBaseInstance", "class_ogre_1_1_d3_d9_render_system.html#a85520f23e22840e951573681d4baef4f", null ],
     [ "_resetMetrics", "class_ogre_1_1_d3_d9_render_system.html#ac277fde4bc118aab022798181aa9afeb", null ],
-    [ "_resourceTransitionCreated", "class_ogre_1_1_d3_d9_render_system.html#adceb84c1be629865821a15c74d4f0c4f", null ],
-    [ "_resourceTransitionDestroyed", "class_ogre_1_1_d3_d9_render_system.html#a3aef1fb3705642dca6e6c243c456cca1", null ],
     [ "_resumeFrame", "class_ogre_1_1_d3_d9_render_system.html#a21e6f22c4f85330f8f546f4469f23fbe", null ],
     [ "_setAlphaRejectSettings", "class_ogre_1_1_d3_d9_render_system.html#ab63c18908e608834b601298afd2da197", null ],
     [ "_setBindingType", "class_ogre_1_1_d3_d9_render_system.html#ae197c344b0b2dce1739e3c566c280f8c", null ],
@@ -100,7 +98,7 @@ var class_ogre_1_1_d3_d9_render_system =
     [ "_setTessellationDomainTexture", "class_ogre_1_1_d3_d9_render_system.html#aba600f21b87a9f259f435645b5e8e686", null ],
     [ "_setTessellationHullTexture", "class_ogre_1_1_d3_d9_render_system.html#ac95050584b686d5ccbe6464642a56c12", null ],
     [ "_setTexture", "class_ogre_1_1_d3_d9_render_system.html#acc8659aa8149972ca8c1175199110d7d", null ],
-    [ "_setTexture", "class_ogre_1_1_d3_d9_render_system.html#a0949c58c2938c0fe39e8f6d86be131f5", null ],
+    [ "_setTexture", "class_ogre_1_1_d3_d9_render_system.html#a7fd55c280458295605c05553b6d37b2c", null ],
     [ "_setTextureAddressingMode", "class_ogre_1_1_d3_d9_render_system.html#a52779ba1276abbe4b5da48c2018b2061", null ],
     [ "_setTextureBlendMode", "class_ogre_1_1_d3_d9_render_system.html#ad0ce107404650d8b2ba8fcfba1448b60", null ],
     [ "_setTextureBorderColour", "class_ogre_1_1_d3_d9_render_system.html#a8f2284cd8c24afda7c14f9570f400698", null ],
@@ -132,6 +130,7 @@ var class_ogre_1_1_d3_d9_render_system =
     [ "addClipPlane", "class_ogre_1_1_d3_d9_render_system.html#abe0fbe6b4972baf14137235fe3f6c499", null ],
     [ "addClipPlane", "class_ogre_1_1_d3_d9_render_system.html#a2eb75175291761881bdc0d73ec379089", null ],
     [ "addListener", "class_ogre_1_1_d3_d9_render_system.html#ada5d01c8a4eb8e64140d92fce245800c", null ],
+    [ "addSharedListener", "class_ogre_1_1_d3_d9_render_system.html#a89fe3734e6d495bfb73624ef269305cf", null ],
     [ "areFixedFunctionLightsInViewSpace", "class_ogre_1_1_d3_d9_render_system.html#a008131b65568c0bf072ae3a96203d6c0", null ],
     [ "beginGPUSampleProfile", "class_ogre_1_1_d3_d9_render_system.html#a05c1e2721a42dec9c6482aeb0aeab097", null ],
     [ "beginProfileEvent", "class_ogre_1_1_d3_d9_render_system.html#ac5910601e68f4c7c08370e2b74066d9b", null ],
@@ -142,65 +141,78 @@ var class_ogre_1_1_d3_d9_render_system =
     [ "checkExtension", "class_ogre_1_1_d3_d9_render_system.html#ae869e9f5ca12313ee49fa0743dbcf1f3", null ],
     [ "clearFrameBuffer", "class_ogre_1_1_d3_d9_render_system.html#a80605199eceb6f34f01230242d1f8c41", null ],
     [ "clearFrameBuffer", "class_ogre_1_1_d3_d9_render_system.html#a746af1925b9e07bfc96075b192c19333", null ],
+    [ "compositorWorkspaceBegin", "class_ogre_1_1_d3_d9_render_system.html#a90d567191f24a30cb806ab0a146bf8b2", null ],
+    [ "compositorWorkspaceEnd", "class_ogre_1_1_d3_d9_render_system.html#ab732bb02d12b702817772ccf4973a47f", null ],
+    [ "compositorWorkspaceUpdate", "class_ogre_1_1_d3_d9_render_system.html#a2d2d776006ee7a9fa8fae1ac14265177", null ],
     [ "convertColourValue", "class_ogre_1_1_d3_d9_render_system.html#a80d543b61b1152b0dd0049961be4798e", null ],
-    [ "createHardwareOcclusionQuery", "class_ogre_1_1_d3_d9_render_system.html#aec0537fc834208bf533b48001c9bdc96", null ],
-    [ "createMultiRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#a65753b25abed94453cb78684920fbc93", null ],
-    [ "createRenderPassDescriptor", "class_ogre_1_1_d3_d9_render_system.html#ae281ad421184f50c9d50658ed45434ec", null ],
+    [ "createHardwareOcclusionQuery", "class_ogre_1_1_d3_d9_render_system.html#aceacaef86b50bc57a0eed5793ee26e74", null ],
+    [ "createMultiRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#aa2511e52bd08dced3e30f7002ff67c48", null ],
+    [ "createRenderPassDescriptor", "class_ogre_1_1_d3_d9_render_system.html#acfcf7b4ecf6426ce8358f21fb868321a", null ],
     [ "createStereoDriver", "class_ogre_1_1_d3_d9_render_system.html#a296a4b8cb73c61dced451b6e23e95919", null ],
+    [ "debugAnnotationPop", "class_ogre_1_1_d3_d9_render_system.html#afcb3669378e8730fe2c48d7fa6d8a3c1", null ],
+    [ "debugAnnotationPush", "class_ogre_1_1_d3_d9_render_system.html#af880df1d878f28b0aea0f1f818ea940d", null ],
     [ "deinitGPUProfiling", "class_ogre_1_1_d3_d9_render_system.html#ab72dcb00f1cd7eb283521f684f566c58", null ],
     [ "destroyHardwareOcclusionQuery", "class_ogre_1_1_d3_d9_render_system.html#ac4c60bf4c5d4347fd2b9346a90545e2b", null ],
     [ "destroyRenderPassDescriptor", "class_ogre_1_1_d3_d9_render_system.html#a60e5ffa2ec8f2709435c3d11e8a321f6", null ],
     [ "destroyRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#a13fb04ce75bdf6920f3ce3628a19b610", null ],
     [ "destroyRenderWindow", "class_ogre_1_1_d3_d9_render_system.html#a36a560a1e0e171b9a1a19a2748e6dd15", null ],
-    [ "detachRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#a81f207d2d2010d656f55e87d14a87f89", null ],
+    [ "detachRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#a8cc3e0c6a7cad3efc6f8c4e004c9cfa6", null ],
     [ "determineFSAASettings", "class_ogre_1_1_d3_d9_render_system.html#abeb5bc1a5691a572c5dc2f4775cf76c5", null ],
     [ "enableClipPlane", "class_ogre_1_1_d3_d9_render_system.html#aebb369ceba620861ccd3ff8a1cead931", null ],
+    [ "endCopyEncoder", "class_ogre_1_1_d3_d9_render_system.html#a30b893cdd07ccd24f95623ebef2668b7", null ],
+    [ "endGpuDebuggerFrameCapture", "class_ogre_1_1_d3_d9_render_system.html#a0a72b69bed67cdf99239d884748bcb08", null ],
     [ "endGPUSampleProfile", "class_ogre_1_1_d3_d9_render_system.html#abc10607326985e9220635a80fba6c20e", null ],
     [ "endProfileEvent", "class_ogre_1_1_d3_d9_render_system.html#ae849367c0ad6d28ecc8db5d95b3e56d7", null ],
     [ "endRenderPassDescriptor", "class_ogre_1_1_d3_d9_render_system.html#abf307f8d33424add34986bbe82de7b77", null ],
     [ "executeRenderPassDescriptorDelayedActions", "class_ogre_1_1_d3_d9_render_system.html#a3dc08052db357beff034cad183fdfadc", null ],
+    [ "executeResourceTransition", "class_ogre_1_1_d3_d9_render_system.html#ad6efb4ed490715cf068fca69b689403d", null ],
     [ "fireDeviceEvent", "class_ogre_1_1_d3_d9_render_system.html#ace53b06d3e61511f9b2dc6156e31c9a9", null ],
+    [ "fireSharedEvent", "class_ogre_1_1_d3_d9_render_system.html#add0b3b86b8ec2f51d8973b6b3e06448e", null ],
     [ "flushCommands", "class_ogre_1_1_d3_d9_render_system.html#a03042760fb5ad088f8c73883f9d7fe14", null ],
-    [ "flushUAVs", "class_ogre_1_1_d3_d9_render_system.html#a60fd2b1db3514c02213bb82a0c06d4c7", null ],
-    [ "getActiveD3D9Device", "class_ogre_1_1_d3_d9_render_system.html#af275458fafa039df530a9b3242139d29", null ],
-    [ "getActiveD3D9DeviceIfExists", "class_ogre_1_1_d3_d9_render_system.html#a4ce5bef3f937282cfd0c4290e66e0c8f", null ],
-    [ "getCapabilities", "class_ogre_1_1_d3_d9_render_system.html#ac4b66fe49129476323eba9bdca672a36", null ],
+    [ "getActiveD3D9Device", "class_ogre_1_1_d3_d9_render_system.html#a73585609cd73845b9217349725ca278b", null ],
+    [ "getActiveD3D9DeviceIfExists", "class_ogre_1_1_d3_d9_render_system.html#a14902091a74d2a3799b2929f11b2dabe", null ],
+    [ "getBarrierSolver", "class_ogre_1_1_d3_d9_render_system.html#a66b206faf53b0b3ff54b10153c76b66f", null ],
+    [ "getBoundUav", "class_ogre_1_1_d3_d9_render_system.html#afb6f61d5c70531c1eb718cdfbefb0330", null ],
+    [ "getCapabilities", "class_ogre_1_1_d3_d9_render_system.html#aa6c951fc82f49ccf22787fcd1e7ee451", null ],
     [ "getColourVertexElementType", "class_ogre_1_1_d3_d9_render_system.html#a1725114e0149f084486dc60abc62bbdc", null ],
-    [ "getConfigOptions", "class_ogre_1_1_d3_d9_render_system.html#ab8e3da0c3876134f9c800409ba84f54d", null ],
-    [ "getCurrentPassDescriptor", "class_ogre_1_1_d3_d9_render_system.html#a6ec66a0d8c51ded50185ac9f90670ae4", null ],
-    [ "getCurrentRenderViewports", "class_ogre_1_1_d3_d9_render_system.html#a4f52275d3e3248a49318e3c584bf5515", null ],
+    [ "getConfigOptions", "class_ogre_1_1_d3_d9_render_system.html#aedbb8040eb6e5e9258056680d31bd567", null ],
+    [ "getCurrentPassDescriptor", "class_ogre_1_1_d3_d9_render_system.html#a56f9ba2b074ce74b1e1aed293b5fc6a0", null ],
+    [ "getCurrentRenderViewports", "class_ogre_1_1_d3_d9_render_system.html#a5c3cbe94dd790fa8083aedbbc146edcb", null ],
     [ "getCustomAttribute", "class_ogre_1_1_d3_d9_render_system.html#a97e2c11d3822c064ccb8ef0b52acf289", null ],
     [ "getDebugShaders", "class_ogre_1_1_d3_d9_render_system.html#a05dbfafd87ccda8119c289c266e41ec1", null ],
-    [ "getDepthBufferFor", "class_ogre_1_1_d3_d9_render_system.html#a338829c9e5e3ef7e155c232f64c6a20e", null ],
-    [ "getDeviceManager", "class_ogre_1_1_d3_d9_render_system.html#a6c54141586c08b65890364ad8ddcf563", null ],
-    [ "getDirect3D9", "class_ogre_1_1_d3_d9_render_system.html#aa3f1a981206b7f55462997ed49b68de8", null ],
+    [ "getDepthBufferFor", "class_ogre_1_1_d3_d9_render_system.html#af088707ac4e0c0a0904a50fdc74b7325", null ],
+    [ "getDeviceManager", "class_ogre_1_1_d3_d9_render_system.html#afaf9cf2f1d9cd94d8be47d9047533544", null ],
+    [ "getDirect3D9", "class_ogre_1_1_d3_d9_render_system.html#a62aa32d65cc848c3149767be38e0c244", null ],
     [ "getDisplayMonitorCount", "class_ogre_1_1_d3_d9_render_system.html#a44795018c7a6f424849c23cb3947a240", null ],
-    [ "getDriverVersion", "class_ogre_1_1_d3_d9_render_system.html#a6e6521ead351b0b7a8b2cc519b5f4dd6", null ],
+    [ "getDriverVersion", "class_ogre_1_1_d3_d9_render_system.html#ac7d381c6d59bc7b3d4483746f04e2a90", null ],
     [ "getErrorDescription", "class_ogre_1_1_d3_d9_render_system.html#aaeb93c2e45c81e44b79eb7c2d37bea84", null ],
-    [ "getFriendlyName", "class_ogre_1_1_d3_d9_render_system.html#a024a0b2a832c0fe5455add0a701c8911", null ],
+    [ "getFriendlyName", "class_ogre_1_1_d3_d9_render_system.html#a081f3261185c0e1da3ca9deca506288a", null ],
     [ "getGlobalInstanceVertexBuffer", "class_ogre_1_1_d3_d9_render_system.html#a2a859eea18cd0c3cf0c7876bbab862a4", null ],
-    [ "getGlobalInstanceVertexBufferVertexDeclaration", "class_ogre_1_1_d3_d9_render_system.html#a38924cc348317c9104797536eb29be13", null ],
+    [ "getGlobalInstanceVertexBufferVertexDeclaration", "class_ogre_1_1_d3_d9_render_system.html#ad1a30f09bb15daac26e8e10901525214", null ],
     [ "getGlobalNumberOfInstances", "class_ogre_1_1_d3_d9_render_system.html#af41e08cc1bc54e34d0314f4c9ffa58f6", null ],
     [ "getHorizontalTexelOffset", "class_ogre_1_1_d3_d9_render_system.html#aaa6341e3fe439fffeff5bfffa48ec0e6", null ],
+    [ "getInvertedClipSpaceY", "class_ogre_1_1_d3_d9_render_system.html#a9742abc3eb4609b4fc9cbd7df1051661", null ],
     [ "getInvertVertexWinding", "class_ogre_1_1_d3_d9_render_system.html#a133c89c9430091210e01ac44d638a0a3", null ],
     [ "getMaxBoundViewports", "class_ogre_1_1_d3_d9_render_system.html#a3a83f5a8128df163c7bed5a87a7ee923", null ],
     [ "getMaximumDepthInputValue", "class_ogre_1_1_d3_d9_render_system.html#ab55596f38bfc1ba9721eaa121166d7a5", null ],
-    [ "getMetrics", "class_ogre_1_1_d3_d9_render_system.html#a2e51b45ee14fa30894f79bd9cff33c4a", null ],
+    [ "getMetrics", "class_ogre_1_1_d3_d9_render_system.html#a2c8b21df3f79f69fbcf304fa131cb1f9", null ],
     [ "getMinimumDepthInputValue", "class_ogre_1_1_d3_d9_render_system.html#a14c20f8c89b3ef2a8c71daa22f9f02bd", null ],
     [ "getMultiheadUse", "class_ogre_1_1_d3_d9_render_system.html#a7f5e2beb4bd0d894ee99c6468ba20ee7", null ],
-    [ "getMutableCapabilities", "class_ogre_1_1_d3_d9_render_system.html#ab0aa0cedf1898f8cc70e290703b428c7", null ],
-    [ "getName", "class_ogre_1_1_d3_d9_render_system.html#a6d9c10b490440524ea0b5760e7f486c9", null ],
+    [ "getMutableCapabilities", "class_ogre_1_1_d3_d9_render_system.html#a7125b8a614f54a9750b85c5eba62b474", null ],
+    [ "getName", "class_ogre_1_1_d3_d9_render_system.html#a4062d64949c3f8ed6001af07fecca244", null ],
     [ "getNativeShadingLanguageVersion", "class_ogre_1_1_d3_d9_render_system.html#a9d89d5e2e2f0c2c30e72032eae4482ec", null ],
-    [ "getPixelFormatToShaderType", "class_ogre_1_1_d3_d9_render_system.html#aab8d79eed7ee883f655467858b638489", null ],
-    [ "getRenderSystemEvents", "class_ogre_1_1_d3_d9_render_system.html#a9a240df431ddcd945a4a3c1c1b59abbf", null ],
-    [ "getResourceCreationDevice", "class_ogre_1_1_d3_d9_render_system.html#a429e0d14525aa4022c5bfd54847195cd", null ],
+    [ "getNumPriorityConfigOptions", "class_ogre_1_1_d3_d9_render_system.html#ad48a2e651a88a5f3eecdf60e452878e5", null ],
+    [ "getPixelFormatToShaderType", "class_ogre_1_1_d3_d9_render_system.html#a7040f99ad34bec1fe332a95e1ad6b961", null ],
+    [ "getPriorityConfigOption", "class_ogre_1_1_d3_d9_render_system.html#a9b1ee9f299e9097bec1185a4ec478cf7", null ],
+    [ "getRenderDocApi", "class_ogre_1_1_d3_d9_render_system.html#a5d8f84c242a383d007beabf72b11ef76", null ],
+    [ "getRenderSystemEvents", "class_ogre_1_1_d3_d9_render_system.html#aeca02905d47fa75bfb87a4c07e68d02d", null ],
+    [ "getResourceCreationDevice", "class_ogre_1_1_d3_d9_render_system.html#ad177ce11d6941a706429db4a973faad4", null ],
     [ "getResourceCreationDeviceCount", "class_ogre_1_1_d3_d9_render_system.html#af9b728ddf675afcecfafd0d4d335c63c", null ],
-    [ "getResourceManager", "class_ogre_1_1_d3_d9_render_system.html#a8cc447f47bc9fbf8dcb77fa9f10d4dde", null ],
+    [ "getResourceManager", "class_ogre_1_1_d3_d9_render_system.html#ac27c2134455ce86c7886c8450a0393ae", null ],
     [ "getRSDepthRange", "class_ogre_1_1_d3_d9_render_system.html#a4be8db64459468925237b45d87958f26", null ],
-    [ "getSharedListener", "class_ogre_1_1_d3_d9_render_system.html#af759d985eae38988d9a5b381b81dd22e", null ],
-    [ "getStencilBufferParams", "class_ogre_1_1_d3_d9_render_system.html#a18884872c80f71ca0fb55e3b287b39af", null ],
-    [ "getTextureGpuManager", "class_ogre_1_1_d3_d9_render_system.html#a85439e6174450882b61a78b85f27bfda", null ],
-    [ "getVaoManager", "class_ogre_1_1_d3_d9_render_system.html#a09e99446064460fd33ccfb4712b82407", null ],
+    [ "getStencilBufferParams", "class_ogre_1_1_d3_d9_render_system.html#a0a9b24e0640279f6b6fa90613727d585", null ],
+    [ "getTextureGpuManager", "class_ogre_1_1_d3_d9_render_system.html#a2fc23c559d6e15f6a2d0841bbdf7135a", null ],
+    [ "getVaoManager", "class_ogre_1_1_d3_d9_render_system.html#adacd8a9cdfaf24b2aab87289de657189", null ],
     [ "getVerticalTexelOffset", "class_ogre_1_1_d3_d9_render_system.html#a39666e7dd9fc27b22c82b05715fb3ff5", null ],
     [ "getWBufferEnabled", "class_ogre_1_1_d3_d9_render_system.html#a644d2fd38872cf323c50f63148d27d02", null ],
     [ "hasAnisotropicMipMapFilter", "class_ogre_1_1_d3_d9_render_system.html#a659cb3dfd72379833b0b4898d99f9a48", null ],
@@ -210,24 +222,27 @@ var class_ogre_1_1_d3_d9_render_system =
     [ "isDirectX9Ex", "class_ogre_1_1_d3_d9_render_system.html#a377991202bcd3b2ade63fe13f0540039", null ],
     [ "isGpuProgramBound", "class_ogre_1_1_d3_d9_render_system.html#a1ac003196b5b51384f714924a0041081", null ],
     [ "isReverseDepth", "class_ogre_1_1_d3_d9_render_system.html#a780e5c6941c2f5d1f699dbf3e8c5b869", null ],
+    [ "isSameLayout", "class_ogre_1_1_d3_d9_render_system.html#a387d5fa07b1c096496ce6a97c4f68505", null ],
     [ "isStaticBufferLockable", "class_ogre_1_1_d3_d9_render_system.html#abaa7a52e12f93b4dfe8cad18828ffb5b", null ],
+    [ "loadRenderDocApi", "class_ogre_1_1_d3_d9_render_system.html#ab750bf02b8afe5aefce3a4594541904d", null ],
     [ "markProfileEvent", "class_ogre_1_1_d3_d9_render_system.html#a489d99fe770e4c105434ed13911ce350", null ],
     [ "operator delete", "class_ogre_1_1_d3_d9_render_system.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
     [ "operator delete", "class_ogre_1_1_d3_d9_render_system.html#acb46d4b0a597156d9ba5abc39d127792", null ],
     [ "operator delete", "class_ogre_1_1_d3_d9_render_system.html#a1c727e879a260c37b00ce5505fe8e144", null ],
     [ "operator delete[]", "class_ogre_1_1_d3_d9_render_system.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
     [ "operator delete[]", "class_ogre_1_1_d3_d9_render_system.html#a595ea4c05da8aa987d3800e65d23355d", null ],
-    [ "operator new", "class_ogre_1_1_d3_d9_render_system.html#ac4bdf968b7b9af8a5239a27da73d5711", null ],
-    [ "operator new", "class_ogre_1_1_d3_d9_render_system.html#a421b197ca3a38da17e2eb1531a645fa2", null ],
-    [ "operator new", "class_ogre_1_1_d3_d9_render_system.html#ab78a921e54419be677839cdf15d1f0b8", null ],
-    [ "operator new[]", "class_ogre_1_1_d3_d9_render_system.html#afa2943846ba6a2b5824a12857139cf5e", null ],
-    [ "operator new[]", "class_ogre_1_1_d3_d9_render_system.html#a4be37baef81876985aa1071ad5acc6dd", null ],
+    [ "operator new", "class_ogre_1_1_d3_d9_render_system.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
+    [ "operator new", "class_ogre_1_1_d3_d9_render_system.html#ab422c67a2c8844f410fe822a357cba3b", null ],
+    [ "operator new", "class_ogre_1_1_d3_d9_render_system.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
+    [ "operator new[]", "class_ogre_1_1_d3_d9_render_system.html#adce32528577d71b228692df906ecd17c", null ],
+    [ "operator new[]", "class_ogre_1_1_d3_d9_render_system.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
     [ "postExtraThreadsStarted", "class_ogre_1_1_d3_d9_render_system.html#add5efc1032e4e0cc1540811b1b68113d", null ],
     [ "preExtraThreadsStarted", "class_ogre_1_1_d3_d9_render_system.html#a1054440c7aa6a82c82c3062ecb0822d7", null ],
     [ "queueBindUAVs", "class_ogre_1_1_d3_d9_render_system.html#abd681ab591e98cfe37c76bdac2357d6e", null ],
     [ "registerThread", "class_ogre_1_1_d3_d9_render_system.html#a7bbc4c2f2fcfdc3f4e0a6e01250e39b2", null ],
     [ "reinitialise", "class_ogre_1_1_d3_d9_render_system.html#aad47c7460bff0b9a631b3eb17e296309", null ],
     [ "removeListener", "class_ogre_1_1_d3_d9_render_system.html#a7d9e3b4369f98e46dbea4cb4b9390f9d", null ],
+    [ "removeSharedListener", "class_ogre_1_1_d3_d9_render_system.html#a0c9650fccf5a5e54b8b933786bdbe4fb", null ],
     [ "resetClipPlanes", "class_ogre_1_1_d3_d9_render_system.html#a46a9b1385638112a80bf22fa1a5bf531", null ],
     [ "reverseCompareFunction", "class_ogre_1_1_d3_d9_render_system.html#a6a34f2ded473d4cbaeda6e954f76dbaf", null ],
     [ "setAmbientLight", "class_ogre_1_1_d3_d9_render_system.html#a5c0492ef2b162b8d0297e355c6d93592", null ],
@@ -244,7 +259,6 @@ var class_ogre_1_1_d3_d9_render_system =
     [ "setInvertVertexWinding", "class_ogre_1_1_d3_d9_render_system.html#a697f9a8c12f2d08ccc6185cd7992c238", null ],
     [ "setMetricsRecordingEnabled", "class_ogre_1_1_d3_d9_render_system.html#aabd963520ca3e4e48ad5d64eabc4d76d", null ],
     [ "setScissorTest", "class_ogre_1_1_d3_d9_render_system.html#ada9466da79cf86fde16473cc8bf2c728", null ],
-    [ "setSharedListener", "class_ogre_1_1_d3_d9_render_system.html#ad4936a78d447c0e8be978117c47e9f98", null ],
     [ "setStencilBufferParams", "class_ogre_1_1_d3_d9_render_system.html#a8aad4909174796d54e9b1b56784c4baf", null ],
     [ "setStencilBufferParams", "class_ogre_1_1_d3_d9_render_system.html#a62c4d393915276eb56752890a0029f92", null ],
     [ "setStencilCheckEnabled", "class_ogre_1_1_d3_d9_render_system.html#a17c198d30e84af9d8456b3f9198df09e", null ],
@@ -255,6 +269,7 @@ var class_ogre_1_1_d3_d9_render_system =
     [ "setVertexDeclaration", "class_ogre_1_1_d3_d9_render_system.html#ad11519e92283a6cb4186dc618e037eec", null ],
     [ "setWBufferEnabled", "class_ogre_1_1_d3_d9_render_system.html#a01c339f6e89d82b526fb7725424a4263", null ],
     [ "shutdown", "class_ogre_1_1_d3_d9_render_system.html#af14f1a6b539a896178cebfd8a6282fa7", null ],
+    [ "startGpuDebuggerFrameCapture", "class_ogre_1_1_d3_d9_render_system.html#afe7705e26f10dccebf2e6db0b3d6859e", null ],
     [ "unbindGpuProgram", "class_ogre_1_1_d3_d9_render_system.html#a08255da85acf7431528d739c77d37ec3", null ],
     [ "unregisterThread", "class_ogre_1_1_d3_d9_render_system.html#acca4cb7d57e8b3a190d4599e0f0ac340", null ],
     [ "updateCompositorManager", "class_ogre_1_1_d3_d9_render_system.html#a41328026d8be0e7143402a914f707cf9", null ],
