@@ -1,18 +1,17 @@
 var class_ogre_1_1_render_system =
 [
     [ "Listener", "class_ogre_1_1_render_system_1_1_listener.html", "class_ogre_1_1_render_system_1_1_listener" ],
-    [ "Metrics", "struct_ogre_1_1_render_system_1_1_metrics.html", "struct_ogre_1_1_render_system_1_1_metrics" ],
     [ "RenderSystemContext", "struct_ogre_1_1_render_system_1_1_render_system_context.html", null ],
     [ "RenderSystem", "class_ogre_1_1_render_system.html#a3391b683d588628272d8d9de633e472e", null ],
     [ "~RenderSystem", "class_ogre_1_1_render_system.html#a785f83ff8a4ee8fb21a11c9d6fe5c928", null ],
-    [ "_addMetrics", "class_ogre_1_1_render_system.html#ab4c80dcdf2f20df687035fb8c72797ea", null ],
+    [ "_addMetrics", "class_ogre_1_1_render_system.html#a54ebaf329b7173ef06cbfcd0dff64cb5", null ],
     [ "_beginFrame", "class_ogre_1_1_render_system.html#a80b7ab32b8f82cf340c47d55f6e69881", null ],
     [ "_beginFrameOnce", "class_ogre_1_1_render_system.html#ada60763d5b8ef9cfba1c77ecfe3e4188", null ],
     [ "_cleanupDepthBuffers", "class_ogre_1_1_render_system.html#a93ef27c77c394d18f8c1ba6361dbef98", null ],
     [ "_clearStateAndFlushCommandBuffer", "class_ogre_1_1_render_system.html#a2ee7864ccf7579b46082f2b694d6586a", null ],
     [ "_convertOpenVrProjectionMatrix", "class_ogre_1_1_render_system.html#ad05022b35e523cdba22d993a51fc4b78", null ],
     [ "_convertProjectionMatrix", "class_ogre_1_1_render_system.html#a2228dcfce5ec360f8f421f9544872f01", null ],
-    [ "_createRenderWindow", "class_ogre_1_1_render_system.html#a1686daff9ebf2be74bc36dcb540807bb", null ],
+    [ "_createRenderWindow", "class_ogre_1_1_render_system.html#ab120136ac65bef3def024f27532c03fb", null ],
     [ "_createRenderWindows", "class_ogre_1_1_render_system.html#a2d1a6b690161dcd972d7cfc13b59dc10", null ],
     [ "_dereferenceSharedDepthBuffer", "class_ogre_1_1_render_system.html#a24604b2949b6dfe884b7d87b9ebaf0cc", null ],
     [ "_descriptorSetSamplerCreated", "class_ogre_1_1_render_system.html#a5b3f8e6370d6df438402da2053e0cb54", null ],
@@ -26,9 +25,8 @@ var class_ogre_1_1_render_system =
     [ "_dispatch", "class_ogre_1_1_render_system.html#a861e0f346f675c6fa688e522c0754ad8", null ],
     [ "_endFrame", "class_ogre_1_1_render_system.html#aad966c6f361ac75304c1e03f9ec384c4", null ],
     [ "_endFrameOnce", "class_ogre_1_1_render_system.html#a7918658f5c363617c53f6179d23e63fc", null ],
-    [ "_executeResourceTransition", "class_ogre_1_1_render_system.html#a0c157a039184ac45bf575fb0d00601de", null ],
-    [ "_getCurrentRenderViewport", "class_ogre_1_1_render_system.html#a8bd773d225cea6b0aee804c3c5b2a945", null ],
-    [ "_getDefaultViewportMaterialScheme", "class_ogre_1_1_render_system.html#a3c2256419916cbf7777c9bf8b1f3d716", null ],
+    [ "_getCurrentRenderViewport", "class_ogre_1_1_render_system.html#a51cbd7a790f8bad97ac8983e00fcbfb2", null ],
+    [ "_getDefaultViewportMaterialScheme", "class_ogre_1_1_render_system.html#a6a719f86bcb5458d55bd0cd887f3ed3e", null ],
     [ "_hlmsBlendblockCreated", "class_ogre_1_1_render_system.html#ac33cff318b8ae9c4f1b9a35b97250322", null ],
     [ "_hlmsBlendblockDestroyed", "class_ogre_1_1_render_system.html#a494fc2da2cb98d016803868180cdcbb9", null ],
     [ "_hlmsComputePipelineStateObjectCreated", "class_ogre_1_1_render_system.html#ab7691a6fe2d57613a8ba6a0b5780b313", null ],
@@ -39,9 +37,9 @@ var class_ogre_1_1_render_system =
     [ "_hlmsPipelineStateObjectDestroyed", "class_ogre_1_1_render_system.html#a9120e92d45da9294119cc88f3ad8bd19", null ],
     [ "_hlmsSamplerblockCreated", "class_ogre_1_1_render_system.html#a5df47d554298bec7130841b77b301034", null ],
     [ "_hlmsSamplerblockDestroyed", "class_ogre_1_1_render_system.html#ab4c5501448cb75312320baac3fb05d1d", null ],
-    [ "_initialise", "class_ogre_1_1_render_system.html#ad492a591934a5041709e39cba196099b", null ],
+    [ "_initialise", "class_ogre_1_1_render_system.html#a09fdd814e1b729593686cdbd2a3e3bd7", null ],
     [ "_makeRsProjectionMatrix", "class_ogre_1_1_render_system.html#a37208fe7f2e29b71a2972defdf9d04b2", null ],
-    [ "_pauseFrame", "class_ogre_1_1_render_system.html#a9893de6903d77fe231da1135f5ee00db", null ],
+    [ "_pauseFrame", "class_ogre_1_1_render_system.html#a20ef2d587957ef999a1ecb8459f3db36", null ],
     [ "_render", "class_ogre_1_1_render_system.html#a05164d117632c60852cbcc6c21fd957b", null ],
     [ "_render", "class_ogre_1_1_render_system.html#a1224b23cee7a4967f75cb947ba185b99", null ],
     [ "_render", "class_ogre_1_1_render_system.html#a8a6d8da446a59c5036f3e6711ab4196e", null ],
@@ -54,8 +52,6 @@ var class_ogre_1_1_render_system =
     [ "_renderNoBaseInstance", "class_ogre_1_1_render_system.html#adf4faec7fb049bc5092605c526cf1d72", null ],
     [ "_renderNoBaseInstance", "class_ogre_1_1_render_system.html#a85520f23e22840e951573681d4baef4f", null ],
     [ "_resetMetrics", "class_ogre_1_1_render_system.html#ac277fde4bc118aab022798181aa9afeb", null ],
-    [ "_resourceTransitionCreated", "class_ogre_1_1_render_system.html#adceb84c1be629865821a15c74d4f0c4f", null ],
-    [ "_resourceTransitionDestroyed", "class_ogre_1_1_render_system.html#a3aef1fb3705642dca6e6c243c456cca1", null ],
     [ "_resumeFrame", "class_ogre_1_1_render_system.html#abe9b7d178eb5d0ea90c7b9a35f612f91", null ],
     [ "_setBindingType", "class_ogre_1_1_render_system.html#ae197c344b0b2dce1739e3c566c280f8c", null ],
     [ "_setComputePso", "class_ogre_1_1_render_system.html#af401f9ec22a0f9e21b6166fb263029f9", null ],
@@ -73,7 +69,7 @@ var class_ogre_1_1_render_system =
     [ "_setSurfaceParams", "class_ogre_1_1_render_system.html#aca86be508b2afbbe67e2eac635ac640d", null ],
     [ "_setTessellationDomainTexture", "class_ogre_1_1_render_system.html#aba600f21b87a9f259f435645b5e8e686", null ],
     [ "_setTessellationHullTexture", "class_ogre_1_1_render_system.html#ac95050584b686d5ccbe6464642a56c12", null ],
-    [ "_setTexture", "class_ogre_1_1_render_system.html#a0949c58c2938c0fe39e8f6d86be131f5", null ],
+    [ "_setTexture", "class_ogre_1_1_render_system.html#a7fd55c280458295605c05553b6d37b2c", null ],
     [ "_setTextureBlendMode", "class_ogre_1_1_render_system.html#a33ce98658bb9f6fdb1aca70c8041ef81", null ],
     [ "_setTextureCoordCalculation", "class_ogre_1_1_render_system.html#a8f37341fd724098023aa0be0850302b0", null ],
     [ "_setTextureMatrix", "class_ogre_1_1_render_system.html#a1212c8aa766ec3b309ee2216bec0ef88", null ],
@@ -95,6 +91,7 @@ var class_ogre_1_1_render_system =
     [ "addClipPlane", "class_ogre_1_1_render_system.html#abe0fbe6b4972baf14137235fe3f6c499", null ],
     [ "addClipPlane", "class_ogre_1_1_render_system.html#a2eb75175291761881bdc0d73ec379089", null ],
     [ "addListener", "class_ogre_1_1_render_system.html#ada5d01c8a4eb8e64140d92fce245800c", null ],
+    [ "addSharedListener", "class_ogre_1_1_render_system.html#a89fe3734e6d495bfb73624ef269305cf", null ],
     [ "areFixedFunctionLightsInViewSpace", "class_ogre_1_1_render_system.html#a008131b65568c0bf072ae3a96203d6c0", null ],
     [ "beginGPUSampleProfile", "class_ogre_1_1_render_system.html#a05c1e2721a42dec9c6482aeb0aeab097", null ],
     [ "beginProfileEvent", "class_ogre_1_1_render_system.html#acdcb8c0f6316a444b592882e1b7bb6c6", null ],
@@ -103,75 +100,91 @@ var class_ogre_1_1_render_system =
     [ "bindGpuProgramPassIterationParameters", "class_ogre_1_1_render_system.html#ae1f7904fe5f6a1d39fe8a0621dab7509", null ],
     [ "checkExtension", "class_ogre_1_1_render_system.html#ae869e9f5ca12313ee49fa0743dbcf1f3", null ],
     [ "clearFrameBuffer", "class_ogre_1_1_render_system.html#a80605199eceb6f34f01230242d1f8c41", null ],
+    [ "compositorWorkspaceBegin", "class_ogre_1_1_render_system.html#a90d567191f24a30cb806ab0a146bf8b2", null ],
+    [ "compositorWorkspaceEnd", "class_ogre_1_1_render_system.html#ab732bb02d12b702817772ccf4973a47f", null ],
+    [ "compositorWorkspaceUpdate", "class_ogre_1_1_render_system.html#a2d2d776006ee7a9fa8fae1ac14265177", null ],
     [ "convertColourValue", "class_ogre_1_1_render_system.html#a80d543b61b1152b0dd0049961be4798e", null ],
-    [ "createHardwareOcclusionQuery", "class_ogre_1_1_render_system.html#a2b7725995f951adff614db3874c8566c", null ],
-    [ "createRenderPassDescriptor", "class_ogre_1_1_render_system.html#ae281ad421184f50c9d50658ed45434ec", null ],
-    [ "createRenderSystemCapabilities", "class_ogre_1_1_render_system.html#a4cd432497387d2c630a95ad9c0cd9772", null ],
+    [ "createHardwareOcclusionQuery", "class_ogre_1_1_render_system.html#a6152b6d18e24b703e292e1863be59f6a", null ],
+    [ "createRenderPassDescriptor", "class_ogre_1_1_render_system.html#acfcf7b4ecf6426ce8358f21fb868321a", null ],
+    [ "createRenderSystemCapabilities", "class_ogre_1_1_render_system.html#a38ded42dd485844e9cc3904dd0ac7fcd", null ],
+    [ "debugAnnotationPop", "class_ogre_1_1_render_system.html#afcb3669378e8730fe2c48d7fa6d8a3c1", null ],
+    [ "debugAnnotationPush", "class_ogre_1_1_render_system.html#af880df1d878f28b0aea0f1f818ea940d", null ],
     [ "deinitGPUProfiling", "class_ogre_1_1_render_system.html#ab72dcb00f1cd7eb283521f684f566c58", null ],
     [ "destroyHardwareOcclusionQuery", "class_ogre_1_1_render_system.html#ac4c60bf4c5d4347fd2b9346a90545e2b", null ],
     [ "destroyRenderPassDescriptor", "class_ogre_1_1_render_system.html#a60e5ffa2ec8f2709435c3d11e8a321f6", null ],
     [ "destroyRenderWindow", "class_ogre_1_1_render_system.html#a36a560a1e0e171b9a1a19a2748e6dd15", null ],
+    [ "endCopyEncoder", "class_ogre_1_1_render_system.html#a30b893cdd07ccd24f95623ebef2668b7", null ],
+    [ "endGpuDebuggerFrameCapture", "class_ogre_1_1_render_system.html#a0a72b69bed67cdf99239d884748bcb08", null ],
     [ "endGPUSampleProfile", "class_ogre_1_1_render_system.html#abc10607326985e9220635a80fba6c20e", null ],
     [ "endProfileEvent", "class_ogre_1_1_render_system.html#a1b6abe6712afe1a695d015216ae96459", null ],
     [ "endRenderPassDescriptor", "class_ogre_1_1_render_system.html#abf307f8d33424add34986bbe82de7b77", null ],
     [ "executeRenderPassDescriptorDelayedActions", "class_ogre_1_1_render_system.html#a3dc08052db357beff034cad183fdfadc", null ],
+    [ "executeResourceTransition", "class_ogre_1_1_render_system.html#ad6efb4ed490715cf068fca69b689403d", null ],
+    [ "fireSharedEvent", "class_ogre_1_1_render_system.html#add0b3b86b8ec2f51d8973b6b3e06448e", null ],
     [ "flushCommands", "class_ogre_1_1_render_system.html#a03042760fb5ad088f8c73883f9d7fe14", null ],
-    [ "flushUAVs", "class_ogre_1_1_render_system.html#a60fd2b1db3514c02213bb82a0c06d4c7", null ],
-    [ "getCapabilities", "class_ogre_1_1_render_system.html#ac4b66fe49129476323eba9bdca672a36", null ],
+    [ "getBarrierSolver", "class_ogre_1_1_render_system.html#a66b206faf53b0b3ff54b10153c76b66f", null ],
+    [ "getBoundUav", "class_ogre_1_1_render_system.html#afb6f61d5c70531c1eb718cdfbefb0330", null ],
+    [ "getCapabilities", "class_ogre_1_1_render_system.html#aa6c951fc82f49ccf22787fcd1e7ee451", null ],
     [ "getColourVertexElementType", "class_ogre_1_1_render_system.html#a71bc0ec1bf3837dbcf7f4aa39849bb40", null ],
-    [ "getConfigOptions", "class_ogre_1_1_render_system.html#a7a6236866e64cc19c078383b43872aa8", null ],
-    [ "getCurrentPassDescriptor", "class_ogre_1_1_render_system.html#a6ec66a0d8c51ded50185ac9f90670ae4", null ],
-    [ "getCurrentRenderViewports", "class_ogre_1_1_render_system.html#a4f52275d3e3248a49318e3c584bf5515", null ],
+    [ "getConfigOptions", "class_ogre_1_1_render_system.html#aeaa33d1872953dec3f612016a36f1627", null ],
+    [ "getCurrentPassDescriptor", "class_ogre_1_1_render_system.html#a56f9ba2b074ce74b1e1aed293b5fc6a0", null ],
+    [ "getCurrentRenderViewports", "class_ogre_1_1_render_system.html#a5c3cbe94dd790fa8083aedbbc146edcb", null ],
     [ "getCustomAttribute", "class_ogre_1_1_render_system.html#a97e2c11d3822c064ccb8ef0b52acf289", null ],
     [ "getDebugShaders", "class_ogre_1_1_render_system.html#a05dbfafd87ccda8119c289c266e41ec1", null ],
-    [ "getDepthBufferFor", "class_ogre_1_1_render_system.html#a338829c9e5e3ef7e155c232f64c6a20e", null ],
+    [ "getDepthBufferFor", "class_ogre_1_1_render_system.html#af088707ac4e0c0a0904a50fdc74b7325", null ],
     [ "getDisplayMonitorCount", "class_ogre_1_1_render_system.html#aac481d80a88211d8eed2f5f7dc4c6afe", null ],
-    [ "getDriverVersion", "class_ogre_1_1_render_system.html#a6e6521ead351b0b7a8b2cc519b5f4dd6", null ],
+    [ "getDriverVersion", "class_ogre_1_1_render_system.html#ac7d381c6d59bc7b3d4483746f04e2a90", null ],
     [ "getErrorDescription", "class_ogre_1_1_render_system.html#a847238effa8920edf9aee7aa5b8cd7be", null ],
-    [ "getFriendlyName", "class_ogre_1_1_render_system.html#af74b8367b531b280f80f0f52d87e84bc", null ],
+    [ "getFriendlyName", "class_ogre_1_1_render_system.html#a3f3b7a9d7d40c48725b5c41db0bfab42", null ],
     [ "getGlobalInstanceVertexBuffer", "class_ogre_1_1_render_system.html#a2a859eea18cd0c3cf0c7876bbab862a4", null ],
-    [ "getGlobalInstanceVertexBufferVertexDeclaration", "class_ogre_1_1_render_system.html#a38924cc348317c9104797536eb29be13", null ],
+    [ "getGlobalInstanceVertexBufferVertexDeclaration", "class_ogre_1_1_render_system.html#ad1a30f09bb15daac26e8e10901525214", null ],
     [ "getGlobalNumberOfInstances", "class_ogre_1_1_render_system.html#af41e08cc1bc54e34d0314f4c9ffa58f6", null ],
     [ "getHorizontalTexelOffset", "class_ogre_1_1_render_system.html#a6d706602114e1e4835890cfa4aa6eb2f", null ],
+    [ "getInvertedClipSpaceY", "class_ogre_1_1_render_system.html#a9742abc3eb4609b4fc9cbd7df1051661", null ],
     [ "getInvertVertexWinding", "class_ogre_1_1_render_system.html#a133c89c9430091210e01ac44d638a0a3", null ],
     [ "getMaxBoundViewports", "class_ogre_1_1_render_system.html#a3a83f5a8128df163c7bed5a87a7ee923", null ],
     [ "getMaximumDepthInputValue", "class_ogre_1_1_render_system.html#a19ea5b0880338661d1162987a22ab827", null ],
-    [ "getMetrics", "class_ogre_1_1_render_system.html#a2e51b45ee14fa30894f79bd9cff33c4a", null ],
+    [ "getMetrics", "class_ogre_1_1_render_system.html#a2c8b21df3f79f69fbcf304fa131cb1f9", null ],
     [ "getMinimumDepthInputValue", "class_ogre_1_1_render_system.html#a5ab53272b5edee4565c05caa605061d3", null ],
-    [ "getMutableCapabilities", "class_ogre_1_1_render_system.html#ab0aa0cedf1898f8cc70e290703b428c7", null ],
-    [ "getName", "class_ogre_1_1_render_system.html#a19b810b6fe61b526010812e9af80bf63", null ],
+    [ "getMutableCapabilities", "class_ogre_1_1_render_system.html#a7125b8a614f54a9750b85c5eba62b474", null ],
+    [ "getName", "class_ogre_1_1_render_system.html#af065d694a866bedee81bcf01e1da55a2", null ],
     [ "getNativeShadingLanguageVersion", "class_ogre_1_1_render_system.html#a9d89d5e2e2f0c2c30e72032eae4482ec", null ],
-    [ "getPixelFormatToShaderType", "class_ogre_1_1_render_system.html#aab8d79eed7ee883f655467858b638489", null ],
-    [ "getRenderSystemEvents", "class_ogre_1_1_render_system.html#a9a240df431ddcd945a4a3c1c1b59abbf", null ],
+    [ "getNumPriorityConfigOptions", "class_ogre_1_1_render_system.html#ad48a2e651a88a5f3eecdf60e452878e5", null ],
+    [ "getPixelFormatToShaderType", "class_ogre_1_1_render_system.html#a7040f99ad34bec1fe332a95e1ad6b961", null ],
+    [ "getPriorityConfigOption", "class_ogre_1_1_render_system.html#a9b1ee9f299e9097bec1185a4ec478cf7", null ],
+    [ "getRenderDocApi", "class_ogre_1_1_render_system.html#a5d8f84c242a383d007beabf72b11ef76", null ],
+    [ "getRenderSystemEvents", "class_ogre_1_1_render_system.html#aeca02905d47fa75bfb87a4c07e68d02d", null ],
     [ "getRSDepthRange", "class_ogre_1_1_render_system.html#a4be8db64459468925237b45d87958f26", null ],
-    [ "getSharedListener", "class_ogre_1_1_render_system.html#af759d985eae38988d9a5b381b81dd22e", null ],
-    [ "getStencilBufferParams", "class_ogre_1_1_render_system.html#a18884872c80f71ca0fb55e3b287b39af", null ],
-    [ "getTextureGpuManager", "class_ogre_1_1_render_system.html#a85439e6174450882b61a78b85f27bfda", null ],
-    [ "getVaoManager", "class_ogre_1_1_render_system.html#a09e99446064460fd33ccfb4712b82407", null ],
+    [ "getStencilBufferParams", "class_ogre_1_1_render_system.html#a0a9b24e0640279f6b6fa90613727d585", null ],
+    [ "getTextureGpuManager", "class_ogre_1_1_render_system.html#a2fc23c559d6e15f6a2d0841bbdf7135a", null ],
+    [ "getVaoManager", "class_ogre_1_1_render_system.html#adacd8a9cdfaf24b2aab87289de657189", null ],
     [ "getVerticalTexelOffset", "class_ogre_1_1_render_system.html#a18238c4b41bfaab6ca5f5e19e20d0d55", null ],
     [ "getWBufferEnabled", "class_ogre_1_1_render_system.html#a644d2fd38872cf323c50f63148d27d02", null ],
     [ "hasAnisotropicMipMapFilter", "class_ogre_1_1_render_system.html#a2532f63fc0d0c2e76b6b61c804829628", null ],
     [ "initGPUProfiling", "class_ogre_1_1_render_system.html#a417adea02b63de86acf6ae6edaa13ac8", null ],
     [ "isGpuProgramBound", "class_ogre_1_1_render_system.html#a1ac003196b5b51384f714924a0041081", null ],
     [ "isReverseDepth", "class_ogre_1_1_render_system.html#a780e5c6941c2f5d1f699dbf3e8c5b869", null ],
+    [ "isSameLayout", "class_ogre_1_1_render_system.html#a387d5fa07b1c096496ce6a97c4f68505", null ],
     [ "isStaticBufferLockable", "class_ogre_1_1_render_system.html#a319564dc746b19bb9a1490a473227b20", null ],
+    [ "loadRenderDocApi", "class_ogre_1_1_render_system.html#ab750bf02b8afe5aefce3a4594541904d", null ],
     [ "markProfileEvent", "class_ogre_1_1_render_system.html#aaafa1dfb6fcf978786add8ee2b02dfb5", null ],
     [ "operator delete", "class_ogre_1_1_render_system.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
     [ "operator delete", "class_ogre_1_1_render_system.html#acb46d4b0a597156d9ba5abc39d127792", null ],
     [ "operator delete", "class_ogre_1_1_render_system.html#a1c727e879a260c37b00ce5505fe8e144", null ],
     [ "operator delete[]", "class_ogre_1_1_render_system.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
     [ "operator delete[]", "class_ogre_1_1_render_system.html#a595ea4c05da8aa987d3800e65d23355d", null ],
-    [ "operator new", "class_ogre_1_1_render_system.html#ac4bdf968b7b9af8a5239a27da73d5711", null ],
-    [ "operator new", "class_ogre_1_1_render_system.html#a421b197ca3a38da17e2eb1531a645fa2", null ],
-    [ "operator new", "class_ogre_1_1_render_system.html#ab78a921e54419be677839cdf15d1f0b8", null ],
-    [ "operator new[]", "class_ogre_1_1_render_system.html#afa2943846ba6a2b5824a12857139cf5e", null ],
-    [ "operator new[]", "class_ogre_1_1_render_system.html#a4be37baef81876985aa1071ad5acc6dd", null ],
+    [ "operator new", "class_ogre_1_1_render_system.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
+    [ "operator new", "class_ogre_1_1_render_system.html#ab422c67a2c8844f410fe822a357cba3b", null ],
+    [ "operator new", "class_ogre_1_1_render_system.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
+    [ "operator new[]", "class_ogre_1_1_render_system.html#adce32528577d71b228692df906ecd17c", null ],
+    [ "operator new[]", "class_ogre_1_1_render_system.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
     [ "postExtraThreadsStarted", "class_ogre_1_1_render_system.html#a460fb2b67acdea8e3a72933e0348a82d", null ],
     [ "preExtraThreadsStarted", "class_ogre_1_1_render_system.html#a77766da49c29112c390fde51069f543a", null ],
     [ "queueBindUAVs", "class_ogre_1_1_render_system.html#abd681ab591e98cfe37c76bdac2357d6e", null ],
     [ "registerThread", "class_ogre_1_1_render_system.html#aae6874b97f0b5cb00e0bf32e10652540", null ],
     [ "reinitialise", "class_ogre_1_1_render_system.html#a32e21b240c7b6c75eab05cbc870f9868", null ],
     [ "removeListener", "class_ogre_1_1_render_system.html#a7d9e3b4369f98e46dbea4cb4b9390f9d", null ],
+    [ "removeSharedListener", "class_ogre_1_1_render_system.html#a0c9650fccf5a5e54b8b933786bdbe4fb", null ],
     [ "resetClipPlanes", "class_ogre_1_1_render_system.html#a46a9b1385638112a80bf22fa1a5bf531", null ],
     [ "reverseCompareFunction", "class_ogre_1_1_render_system.html#a6a34f2ded473d4cbaeda6e954f76dbaf", null ],
     [ "setClipPlanes", "class_ogre_1_1_render_system.html#a23cc0a7d87b77ec3d0a34e92335bec1a", null ],
@@ -185,11 +198,11 @@ var class_ogre_1_1_render_system =
     [ "setGlobalNumberOfInstances", "class_ogre_1_1_render_system.html#a3e31b243ba86e2114925a99b2c2825e1", null ],
     [ "setInvertVertexWinding", "class_ogre_1_1_render_system.html#a697f9a8c12f2d08ccc6185cd7992c238", null ],
     [ "setMetricsRecordingEnabled", "class_ogre_1_1_render_system.html#aabd963520ca3e4e48ad5d64eabc4d76d", null ],
-    [ "setSharedListener", "class_ogre_1_1_render_system.html#ad4936a78d447c0e8be978117c47e9f98", null ],
     [ "setStencilBufferParams", "class_ogre_1_1_render_system.html#a62c4d393915276eb56752890a0029f92", null ],
     [ "setUavStartingSlot", "class_ogre_1_1_render_system.html#a2d0de2f7b75ffb2d4048534ebe90bb73", null ],
     [ "setWBufferEnabled", "class_ogre_1_1_render_system.html#a01c339f6e89d82b526fb7725424a4263", null ],
     [ "shutdown", "class_ogre_1_1_render_system.html#a987cf400154a21403b4ff5192d423971", null ],
+    [ "startGpuDebuggerFrameCapture", "class_ogre_1_1_render_system.html#afe7705e26f10dccebf2e6db0b3d6859e", null ],
     [ "unregisterThread", "class_ogre_1_1_render_system.html#a64138779fab3c6b157f2de40c3831e10", null ],
     [ "updateCompositorManager", "class_ogre_1_1_render_system.html#a41328026d8be0e7143402a914f707cf9", null ],
     [ "useCustomRenderSystemCapabilities", "class_ogre_1_1_render_system.html#a6219a2d1f92be5548983a03de9522365", null ],
