@@ -1,5 +1,60 @@
 var manual =
 [
+    [ "Ogre Next Samples (Feature demonstrations)", "_samples.html", [
+      [ "Showcase: Forward3D", "_samples.html#forward3d", null ],
+      [ "Showcase: HDR", "_samples.html#hdr", null ],
+      [ "Showcase: HDR/SMAA", "_samples.html#hdrsmaa", null ],
+      [ "Showcase: PBS Materials", "_samples.html#pbsmaterials", null ],
+      [ "Showcase: Post Processing", "_samples.html#postprocessing", null ],
+      [ "API Usage: Animation tag points", "_samples.html#animationtagpoints", null ],
+      [ "API Usage: Area Light Approximation", "_samples.html#arealighapprox", null ],
+      [ "API Usage: Custom Renderable", "_samples.html#customrenderable", null ],
+      [ "API Usage: Decals", "_samples.html#decals", null ],
+      [ "API Usage: Dynamic Geometry", "_samples.html#dynamicgeometry", null ],
+      [ "API Usage: IES Photometric Profiles", "_samples.html#iesprofiles", null ],
+      [ "API Usage: Shared Skeleton", "_samples.html#sharedskeleton", null ],
+      [ "API Usage: Instanced Stereo", "_samples.html#instancedstero", null ],
+      [ "API Usage: Instant Radiosity", "_samples.html#instantradiosity", null ],
+      [ "API Usage: Local Reflections Using Parallax Corrected Cubemaps", "_samples.html#localcubemaps", null ],
+      [ "API Usage: Local Reflections Using Parallax Corrected Cubemaps With Manual Probes", "_samples.html#localcubemapsmp", null ],
+      [ "API Usage: Automatic LOD Generation", "_samples.html#autolod", null ],
+      [ "API Usage: Morph Animations", "_samples.html#morphanimation", null ],
+      [ "API Usage: Automatically Placed Parallax Corrected Cubemap Probes Via PccPerPixelGridPlacement", "_samples.html#autopcc", null ],
+      [ "API Usage: Planar Reflections", "_samples.html#planarreflections", null ],
+      [ "API Usage: Refractions", "_samples.html#refractions", null ],
+      [ "API Usage: SceneFormat Export / Import Sample", "_samples.html#sceneformat", null ],
+      [ "API Usage: Screen Space Reflections", "_samples.html#ssreflections", null ],
+      [ "API Usage: Shadow Map Debugging", "_samples.html#shadowdebug", null ],
+      [ "API Usage: Shadow Map From Code", "_samples.html#shadowfromcode", null ],
+      [ "API Usage: Static Shadow Map", "_samples.html#staticshadowmap", null ],
+      [ "API Usage: Stencil Test", "_samples.html#stenciltest", null ],
+      [ "API Usage: Stereo Rendering", "_samples.html#stereorendering", null ],
+      [ "API Usage: Updating Decals And Area Lights' Textures", "_samples.html#updatedecal", null ],
+      [ "API Usage: Ogre V1 Interfaces", "_samples.html#v1interface", null ],
+      [ "API Usage: Ogre Next Manual Object", "_samples.html#onmanualobject", null ],
+      [ "API Usage: Ogre Next V2 Meshes", "_samples.html#v2Mesh", null ],
+      [ "Tutorial: Tutorial 00 - Basic", "_samples.html#tutorial00", null ],
+      [ "Tutorial: Tutorial 01 - Initialisation", "_samples.html#tutorial01", null ],
+      [ "Tutorial: Tutorial 02 - Variable Framerate", "_samples.html#tutorial02", null ],
+      [ "Tutorial: Tutorial 03 - Deterministic Loop", "_samples.html#tutorial03", null ],
+      [ "Tutorial: Tutorial 04 - Interpolation Loop", "_samples.html#tutorial04", null ],
+      [ "Tutorial: Tutorial 05 - Multithreading Basics", "_samples.html#tutorial05", null ],
+      [ "Tutorial: Tutorial 06 - Multithreading", "_samples.html#tutorial06", null ],
+      [ "Tutorial: Compute 01 - UAV Textures", "_samples.html#compute01", null ],
+      [ "Tutorial: Compute 02 - UAV Buffers", "_samples.html#compute02", null ],
+      [ "Tutorial: Distortion", "_samples.html#tut_distortion", null ],
+      [ "Tutorial: Dynamic Cube Map", "_samples.html#dyncubemap", null ],
+      [ "Tutorial: EGL Headless", "_samples.html#eglheadless", null ],
+      [ "Tutorial: Open VR", "_samples.html#openVR", null ],
+      [ "Tutorial: Reconstructing Position From Depth", "_samples.html#reconpfromd", null ],
+      [ "Tutorial: Rendering Sky As A Postprocess With A Single Shader", "_samples.html#skypost", null ],
+      [ "Tutorial: SMAA", "_samples.html#SMAA", null ],
+      [ "Tutorial: SSAO", "_samples.html#ssao", null ],
+      [ "Tutorial: Terra Terrain", "_samples.html#terrain", null ],
+      [ "Tutorial: Texture Baking", "_samples.html#texturebaking", null ],
+      [ "Tutorial: UAV Setup 1 Example", "_samples.html#uav1", null ],
+      [ "Tutorial: UAV Setup 2 Example", "_samples.html#uav2", null ]
+    ] ],
     [ "Changes: Objects, Scene & Nodes", "_ogre20_changes.html", [
       [ "Names are now optional", "_ogre20_changes.html#NamesAreNowOptional", null ],
       [ "How to debug MovableObjects' (and Nodes) data", "_ogre20_changes.html#HowToDebugMovableObjectsData", [
@@ -50,6 +105,7 @@ var manual =
           [ "quad", "compositor.html#CompositorNodesPassesQuad", null ],
           [ "resolve", "compositor.html#CompositorNodesPassesResolve", null ],
           [ "render_scene", "compositor.html#CompositorNodesPassesRenderScene", null ],
+          [ "shadows", "compositor.html#CompositorNodesPassesShadows", null ],
           [ "stencil", "compositor.html#CompositorNodesPassesStencil", null ],
           [ "uav_queue", "compositor.html#CompositorNodesPassesUavQueue", [
             [ "Synchronization", "compositor.html#CompositorNodesPassesUavQueueSync", null ]
@@ -91,8 +147,37 @@ var manual =
         [ "Viewport modifier mask", "compositor.html#CompositorWorkspacesStereoViewportMask", null ],
         [ "Execution mask", "compositor.html#CompositorWorkspacesStereoExecutionMask", null ],
         [ "Default values", "compositor.html#CompositorWorkspacesStereoDefaultValues", null ]
+      ] ],
+      [ "Advanced MSAA", "compositor.html#autotoc_md70", [
+        [ "What is MSAA?", "compositor.html#autotoc_md71", [
+          [ "Supersampling Antialiasing (SSAA) vs MSAA", "compositor.html#autotoc_md72", null ],
+          [ "MSAA approach to the problem", "compositor.html#autotoc_md73", null ]
+        ] ],
+        [ "Ogre + MSAA with Implicit Resolves", "compositor.html#autotoc_md74", null ],
+        [ "Ogre + MSAA with Explicit Resolves", "compositor.html#autotoc_md75", null ]
       ] ]
     ] ],
+    [ "Global Illumination Methods", "_gi_methods.html", [
+      [ "Ambient Lighting", "_gi_methods.html#GiAmbientLighting", [
+        [ "Flat", "_gi_methods.html#GiAmbientLightingFlat", null ],
+        [ "Hemisphere", "_gi_methods.html#GiAmbientLightingHemisphere", null ],
+        [ "Spherical Harmonics", "_gi_methods.html#GiAmbientLightingSH", null ]
+      ] ],
+      [ "Parallax Corrected Cubemaps (PCC)", "_gi_methods.html#GiPCC", [
+        [ "Auto PCC", "_gi_methods.html#GiPCCAuto", null ],
+        [ "Manual PCC", "_gi_methods.html#GiPCCManual", null ]
+      ] ],
+      [ "Per Pixel PCC", "_gi_methods.html#GiPPPCC", [
+        [ "PCC Per Pixel Grid Placement", "_gi_methods.html#GiPPGridPlacement", null ]
+      ] ],
+      [ "Instant Radiosity", "_gi_methods.html#GiInstantRadiosity", null ],
+      [ "Irradiance Volume", "_gi_methods.html#GiIrradianceVolume", null ],
+      [ "Voxel Cone Tracing (aka VCT)", "_gi_methods.html#GiVCT", [
+        [ "VCT + Per Pixel PCC Hybrid", "_gi_methods.html#GiVCTPlusPPPCC", null ]
+      ] ],
+      [ "Irradiance Field with Depth (IFD)", "_gi_methods.html#GiIFD", null ],
+      [ "What technique should I choose?", "_gi_methods.html#GiWhatTechniqueChoose", null ]
+    ] ],
     [ "Instancing", "instancing.html", [
       [ "What is instancing?", "instancing.html#WhatIsInstancing", null ],
       [ "Instancing 101", "instancing.html#Instancing101", [
@@ -177,7 +262,8 @@ var manual =
         ] ],
         [ "Manual: Texture packs", "hlms.html#HlmsTextureManagerTexturePacks", null ],
         [ "Watching out for memory consumption", "hlms.html#HlmsTextureManagerWatchOutMemory", [
-          [ "Additional memory considerations", "hlms.html#HlmsTextureManagerWatchOutMemoryConsiderations", null ]
+          [ "Additional memory considerations", "hlms.html#HlmsTextureManagerWatchOutMemoryConsiderations", null ],
+          [ "setWorkerThreadMinimumBudget warning", "hlms.html#setWorkerThreadMinimumBudget", null ]
         ] ]
       ] ],
       [ "Troubleshooting", "hlms.html#HlmsTroubleshooting", [
@@ -199,36 +285,87 @@ var manual =
       ] ],
       [ "Post-processing the command buffer", "commandbuffer.html#CommandBufferPostProcessing", null ]
     ] ],
-    [ "What's new in Ogre 2.2", "_ogre22_changes.html", [
-      [ "Load Store semantics", "_ogre22_changes.html#autotoc_md19", [
-        [ "Now that we’ve explained how TBDRs work, we can explain load and store actions", "_ogre22_changes.html#autotoc_md20", null ]
+    [ "Terra System", "_terra_system.html", [
+      [ "Vertex-bufferless rendering", "_terra_system.html#autotoc_md61", null ],
+      [ "Vertex Trick in Terra", "_terra_system.html#autotoc_md62", null ],
+      [ "Terra cells", "_terra_system.html#autotoc_md63", [
+        [ "First layer, the 4x4 block", "_terra_system.html#autotoc_md64", null ],
+        [ "Outer layers", "_terra_system.html#autotoc_md65", null ]
       ] ],
-      [ "More control over MSAA", "_ogre22_changes.html#autotoc_md21", null ],
-      [ "Porting to Ogre 2.2 from 2.1", "_ogre22_changes.html#autotoc_md22", [
-        [ "PixelFormats", "_ogre22_changes.html#autotoc_md23", [
-          [ "Common pixel format equivalencies", "_ogre22_changes.html#autotoc_md24", null ]
+      [ "Skirts", "_terra_system.html#autotoc_md66", null ],
+      [ "Shadows", "_terra_system.html#autotoc_md67", null ],
+      [ "Shading", "_terra_system.html#autotoc_md68", null ],
+      [ "Why is it not a component?", "_terra_system.html#autotoc_md69", null ]
+    ] ],
+    [ "Tunning memory consumption and resources", "_tuning_memory_resources.html", [
+      [ "Grouping textures by type", "_tuning_memory_resources.html#GroupingTexturesByType", null ],
+      [ "Dynamic vs Default buffers", "_tuning_memory_resources.html#DynamicVsDefaultBuffers", null ],
+      [ "Tweaking default memory consumption by VaoManager", "_tuning_memory_resources.html#TweakingVaoManager", [
+        [ "Vulkan and <tt>TEXTURES_OPTIMAL</tt>", "_tuning_memory_resources.html#autotoc_md28", null ]
+      ] ]
+    ] ],
+    [ "What's new in Ogre 2.2", "_ogre22_changes.html", [
+      [ "Load Store semantics", "_ogre22_changes.html#autotoc_md29", [
+        [ "Now that we’ve explained how TBDRs work, we can explain load and store actions", "_ogre22_changes.html#autotoc_md30", null ]
+      ] ],
+      [ "More control over MSAA", "_ogre22_changes.html#autotoc_md31", null ],
+      [ "Porting to Ogre 2.2 from 2.1", "_ogre22_changes.html#autotoc_md32", [
+        [ "PixelFormats", "_ogre22_changes.html#autotoc_md33", [
+          [ "Common pixel format equivalencies", "_ogre22_changes.html#autotoc_md34", null ]
         ] ],
-        [ "Useful code snippets", "_ogre22_changes.html#autotoc_md25", [
-          [ "Create a TextureGpu based on a file", "_ogre22_changes.html#autotoc_md26", null ],
-          [ "Create a TextureGpu based that you manually fill", "_ogre22_changes.html#autotoc_md27", null ],
-          [ "Uploading data to a TextureGpu", "_ogre22_changes.html#autotoc_md28", null ],
-          [ "Upload streaming", "_ogre22_changes.html#autotoc_md29", null ],
-          [ "Downloading data from TextureGpu into CPU", "_ogre22_changes.html#autotoc_md30", null ],
-          [ "Downloading streaming", "_ogre22_changes.html#autotoc_md31", null ]
+        [ "Useful code snippets", "_ogre22_changes.html#autotoc_md35", [
+          [ "Create a TextureGpu based on a file", "_ogre22_changes.html#autotoc_md36", null ],
+          [ "Create a TextureGpu based that you manually fill", "_ogre22_changes.html#autotoc_md37", null ],
+          [ "Uploading data to a TextureGpu", "_ogre22_changes.html#autotoc_md38", null ],
+          [ "Upload streaming", "_ogre22_changes.html#autotoc_md39", null ],
+          [ "Downloading data from TextureGpu into CPU", "_ogre22_changes.html#autotoc_md40", null ],
+          [ "Downloading streaming", "_ogre22_changes.html#autotoc_md41", null ]
         ] ]
       ] ],
-      [ "Difference between depth, numSlices and depthOrSlices", "_ogre22_changes.html#autotoc_md32", null ],
-      [ "Memory layout of textures and images", "_ogre22_changes.html#autotoc_md33", null ],
-      [ "Troubleshooting errors", "_ogre22_changes.html#autotoc_md34", null ],
-      [ "RenderPassDescriptors", "_ogre22_changes.html#autotoc_md35", null ],
-      [ "DescriptorSetTexture & co.", "_ogre22_changes.html#autotoc_md36", null ],
-      [ "Does 2.2 interoperate well with the HLMS texture arrays?", "_ogre22_changes.html#autotoc_md37", null ],
-      [ "Hlms porting", "_ogre22_changes.html#autotoc_md38", null ],
-      [ "Things to watch out when porting", "_ogre22_changes.html#autotoc_md39", null ]
+      [ "Difference between depth, numSlices and depthOrSlices", "_ogre22_changes.html#autotoc_md42", null ],
+      [ "Memory layout of textures and images", "_ogre22_changes.html#autotoc_md43", null ],
+      [ "Troubleshooting errors", "_ogre22_changes.html#autotoc_md44", null ],
+      [ "RenderPassDescriptors", "_ogre22_changes.html#autotoc_md45", null ],
+      [ "DescriptorSetTexture & co.", "_ogre22_changes.html#autotoc_md46", null ],
+      [ "Does 2.2 interoperate well with the HLMS texture arrays?", "_ogre22_changes.html#autotoc_md47", null ],
+      [ "Hlms porting", "_ogre22_changes.html#autotoc_md48", null ],
+      [ "Things to watch out when porting", "_ogre22_changes.html#autotoc_md49", null ]
     ] ],
     [ "Behavor of StagingTexture in D3D11", "_behavor_staging_texture_d3_d11.html", [
-      [ "Attempting to be contiguous", "_behavor_staging_texture_d3_d11.html#autotoc_md16", null ],
-      [ "Slicing in 3", "_behavor_staging_texture_d3_d11.html#autotoc_md17", null ],
-      [ "Slicing in the middle", "_behavor_staging_texture_d3_d11.html#autotoc_md18", null ]
+      [ "Attempting to be contiguous", "_behavor_staging_texture_d3_d11.html#autotoc_md17", null ],
+      [ "Slicing in 3", "_behavor_staging_texture_d3_d11.html#autotoc_md18", null ],
+      [ "Slicing in the middle", "_behavor_staging_texture_d3_d11.html#autotoc_md19", null ]
+    ] ],
+    [ "What's new in Ogre 2.3", "_ogre23_changes.html", [
+      [ "Switch importV1 to createByImportingV1", "_ogre23_changes.html#autotoc_md50", null ],
+      [ "Shadow's Normal Offset Bias", "_ogre23_changes.html#autotoc_md51", null ],
+      [ "Unlit vertex and pixel shaders unified", "_ogre23_changes.html#autotoc_md52", null ],
+      [ "Added HlmsMacroblock::mDepthClamp", "_ogre23_changes.html#autotoc_md53", null ],
+      [ "Added shadow pancaking", "_ogre23_changes.html#autotoc_md54", null ],
+      [ "Other relevant information when porting", "_ogre23_changes.html#autotoc_md55", [
+        [ "Do not call notifyDataIsReady more than needed", "_ogre23_changes.html#autotoc_md56", null ],
+        [ "Global changes for Vulkan compatibility:", "_ogre23_changes.html#autotoc_md57", null ]
+      ] ]
+    ] ],
+    [ "Root Layouts", "_root_layouts.html", [
+      [ "Old APIs (i.e. D3D11 and GL)", "_root_layouts.html#RootLayoutsOldAPIs", null ],
+      [ "New APIs and Root Layouts", "_root_layouts.html#RootLayoutsNewAPIs", null ],
+      [ "Setting up root layouts", "_root_layouts.html#RootLayoutsSettingUp", [
+        [ "Could you have used e.g. \"const_buffers\" : [0,7] instead of [4,7]?", "_root_layouts.html#autotoc_md58", null ]
+      ] ],
+      [ "Declaring Root Layouts in shaders", "_root_layouts.html#RootLayoutsDeclaringInShaders", null ],
+      [ "Baked sets", "_root_layouts.html#RootLayoutsBakedSets", null ],
+      [ "Prefab Root Layouts for low level materials", "_root_layouts.html#RootLayoutPrefabs", null ],
+      [ "Arrays of Textures", "_root_layouts.html#RootLayoutsArraysOfTextures", [
+        [ "C++", "_root_layouts.html#RootLayoutsAoTCpp", null ],
+        [ "Inline shader declaration", "_root_layouts.html#RootLayoutsAoTInlineShader", null ],
+        [ "Automatic", "_root_layouts.html#RootLayoutsAoTAuto", null ],
+        [ "Making GLSL shaders compatible with both Vulkan and OpenGL", "_root_layouts.html#RootLayoutsGLSLForGLandVK", [
+          [ "Example:", "_root_layouts.html#RootLayoutsGLSLForGLandVKExample", [
+            [ "OpenGL", "_root_layouts.html#autotoc_md59", null ],
+            [ "Vulkan", "_root_layouts.html#autotoc_md60", null ]
+          ] ]
+        ] ]
+      ] ]
     ] ]
 ];
\ No newline at end of file
